@@ -418,16 +418,19 @@ async def train(ctx: Context, gpu: int, continue_train: str):
 @click.option(
     "--out", help="Output file name"
 )
+@click.option(
+    "--log", help="Log file name"
+)
 @click.pass_context
 async def eval(
-    ctx: Context, gpu: int, step: int, src: str, ref: str, out: str
+    ctx: Context, gpu: int, step: int, src: str, ref: str, out: str, log: str
 ):
     try:
         workflow = Workflow.load(ctx.obj["project"])
         if src is not None:
             if ref is not None:
                 eval_stage = EvalStage(workflow)
-                await eval_stage.eval_files(gpu, step, src, ref, out)
+                await eval_stage.eval_files(gpu, step, src, ref, out, log)
             else:
                 print("Reference path missing")
         else:
