@@ -39,9 +39,11 @@ class PrepareStage(BaseStage):
         if max_workers is None:
             max_workers = 1
 
-        report = {}
-
         workflow_config = self.workflow.config
+
+        report = workflow_config.prepare.get("report", {})
+        if report is None:
+            report = {}
         to_the_end = False
 
         if (
